@@ -8,6 +8,7 @@ from ansiblelint.rules import AnsibleLintRule
 
 
 def test_unjinja() -> None:
+    """Verify that unjinja understands nested mustache."""
     text = "{{ a }} {% b %} {# try to confuse parsing inside a comment { {{}} } #}"
     output = "JINJA_EXPRESSION JINJA_STATEMENT JINJA_COMMENT"
     assert AnsibleLintRule.unjinja(text) == output
@@ -15,6 +16,7 @@ def test_unjinja() -> None:
 
 @pytest.mark.parametrize('rule_config', (dict(), dict(foo=True, bar=1)))
 def test_rule_config(rule_config: Dict[str, Any], monkeypatch: MonkeyPatch) -> None:
+    """Check that a rule config is inherited from options."""
     rule_id = 'rule-0'
     monkeypatch.setattr(AnsibleLintRule, 'id', rule_id)
     monkeypatch.setitem(options.rules, rule_id, rule_config)
