@@ -78,13 +78,13 @@ class TestEnvVarsInCommand(unittest.TestCase):
     collection = RulesCollection()
     collection.register(EnvVarsInCommandRule())
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.runner = RunFromText(self.collection)
 
-    def test_success(self):
+    def test_success(self) -> None:
         results = self.runner.run_playbook(SUCCESS_PLAY_TASKS)
-        self.assertEqual(0, len(results))
+        assert len(results) == 0
 
-    def test_fail(self):
+    def test_fail(self) -> None:
         results = self.runner.run_playbook(FAIL_PLAY_TASKS)
-        self.assertEqual(2, len(results))
+        assert len(results) == 2
