@@ -22,13 +22,11 @@ class TestMetaVideoLinks(unittest.TestCase):
     collection = RulesCollection()
     collection.register(MetaVideoLinksRule())
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.runner = RunFromText(self.collection)
 
-    def test_video_links(self):
+    def test_video_links(self) -> None:
         results = self.runner.run_role_meta_main(META_VIDEO_LINKS)
-        self.assertIn("Expected item in 'video_links' to be a dictionary", str(results))
-        self.assertIn(
-            "'video_links' to contain only keys 'url' and 'title'", str(results)
-        )
-        self.assertIn("URL format 'www.myvid.com/vid' is not recognized", str(results))
+        assert "Expected item in 'video_links' to be a dictionary" in str(results)
+        assert "'video_links' to contain only keys 'url' and 'title'" in str(results)
+        assert "URL format 'www.myvid.com/vid' is not recognized" in str(results)
