@@ -6,7 +6,7 @@ import pytest
 
 
 @pytest.mark.parametrize('module', ("ansiblelint", "ansiblelint.__main__"))
-def test_import(module):
+def test_import(module: str) -> None:
     """Safeguard that Ansible does not become an implicit import."""
     # We cannot test it directly because our test fixtures already do
     # import Ansible, so we need to test this using a separated process.
